<fieldset class="product-options" id="product-options-wrapper">
    <?php echo $this->getChildHtml('', true, true);?>
    <span style="display:none;" class="scp-please-wait"><img src="<?php echo $this->getSkinUrl('images/scp-ajax-loader.gif') ?>" class="v-middle" alt="" /> &nbsp; <?php echo $this->__('Loading...') ?> &nbsp;</span>
    <?php // add placeholder div for any ajax-loaded custom options ?>
    <div id="SCPcustomOptionsDiv"></div>
    <?php if ($this->hasRequiredOptions()):?>
        <p class="required"><?php echo $this->__('* Required Fields') ?></p>
    <?php endif;?>
</fieldset>
<?php // Change the option decoration rules to remove extraneous line ?>
<script type="text/javascript">
    $$('#product-options-wrapper dl').each(function(label) {
        label.addClassName('last');
    });
</script>
