<?php
#SCP: The core version of this file links straight to products seemingly without doing any visibility checks.
#This version just removes the link
?>
<?php
/**
 * Last order sidebar
 *
 * @see Mage_Sale_Block_Reorder_Sidebar
 */
?>
<?php $_items = $this->getItems()?>
<?php if($_items): ?>
<div class="block block-reorder">
    <div class="block-title">
        <strong><span><?php echo $this->__('My Orders') ?></span></strong>
    </div>
    <form method="post" action="<?php echo $this->getFormActionUrl() ?>" id="reorder-validate-detail">
        <div class="block-content">
            <p class="block-subtitle"><?php echo $this->__('Last ordered items') ?></p>
            <ol id="cart-sidebar-reorder">
            <?php $_showAddButtonFlag = false ?>
            <?php foreach ($_items as $_item): ?>
                <li class="item">
                    <?php if ($this->isItemAvailableForReorder($_item)): ?>
                        <?php $_showAddButtonFlag = true ?>
                        <input type="checkbox" name="order_items[]" id="reorder-item-<?php echo $_item->getId() ?>" value="<?php echo $_item->getId() ?>" title="<?php echo $this->__('Add to Cart') ?>" class="checkbox validate-one-required-by-name" />
                        <script type="text/javascript">
                        //<![CDATA[
                            $('reorder-item-<?php echo $_item->getId() ?>').advaiceContainer = 'cart-sidebar-reorder-advice-container';
                        //]]>
                        </script>
                    <?php endif; ?>
                    <p class="product-name"><?php echo $this->htmlEscape($_item->getName()) ?></p>
                </li>
            <?php endforeach; ?>
            </ol>
            <script type="text/javascript">decorateList('cart-sidebar-reorder')</script>
            <div id="cart-sidebar-reorder-advice-container"></div>
                <div class="actions">
                    <?php if ($_showAddButtonFlag): ?>
                        <button type="submit" title="<?php echo $this->__('Add to Cart') ?>" class="button btn-cart"><span><span><?php echo $this->__('Add to Cart') ?></span></span></button>
                    <?php endif; ?>
                    <a href="<?php echo $this->getUrl('customer/account') ?>"><?php echo $this->__('View All'); ?></a>
                </div>
        </div>
    </form>
</div>
<?php echo $this->getPagerHtml(); ?>
<script type="text/javascript">
//<![CDATA[
    var reorderFormDetail = new VarienForm('reorder-validate-detail');
//]]>
</script>
<?php endif ?>
